EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'CustomLanguages_CreateOrUpdateLanguage',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'CustomLanguage_Id',
    /* Description_Text        */ 'Creates or modifies a custom language.'
GO

IF OBJECT_ID('[CustomLanguages_CreateOrUpdateLanguage]') IS NOT NULL DROP PROCEDURE [CustomLanguages_CreateOrUpdateLanguage]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [CustomLanguages_CreateOrUpdateLanguage]
(
	@Culture_Name VARCHAR(50),
	@Language_Name NVARCHAR(100),
	@Active_Indicator YNINDICATOR,
	@CustomLanguage_Xml XML,
	@CustomLanguage_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @CustomLanguage_Id IS NULL
	BEGIN

		INSERT INTO [CustomLanguages]
		(
			[Culture_Name],
			[Language_Name],
			[Active_Indicator],
			[CustomLanguage_Xml]
		)
		VALUES
		(
			@Culture_Name,
			@Language_Name,
			@Active_Indicator,
			@CustomLanguage_Xml
		)

		SET @CustomLanguage_Id = SCOPE_IDENTITY()

	END
	ELSE
		UPDATE [CustomLanguages]
		   SET [Culture_Name] = @Culture_Name,
		       [Language_Name] = @Language_Name,
			   [Active_Indicator] = @Active_Indicator,
			   [CustomLanguage_Xml] = @CustomLanguage_Xml
		 WHERE [CustomLanguage_Id] = @CustomLanguage_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [CustomLanguages_CreateOrUpdateLanguage] TO [ProGetUser_Role]
GO