EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DashboardFeeds_GetWithCombinedBlobStorage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'DashboardFeeds',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Get the DashboardFeeds list but combines Docker registries that have combined blob storage.'
GO

IF OBJECT_ID('[DashboardFeeds_GetWithCombinedBlobStorage]') IS NOT NULL DROP PROCEDURE [DashboardFeeds_GetWithCombinedBlobStorage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [DashboardFeeds_GetWithCombinedBlobStorage]
AS
BEGIN

	SET NOCOUNT ON

SELECT * 
FROM [DashboardFeeds]  DF
WHERE DF.FeedType_Name != 'Docker' OR (DF.FeedType_Name = 'Docker' AND COALESCE(DF.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)'), 'False') != 'True')

UNION ALL

SELECT [Feed_Id] = -1,
	       [Feed_Name] = 'Docker images',
		   [FeedType_Name],
		   [Package_Download_Count] = (SELECT SUM([Download_Count])
		                                FROM [DockerImages] DI WITH (READUNCOMMITTED)
										JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
										  ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
									JOIN [Feeds] InnerF WITH (READUNCOMMITTED)
										ON DR.[Feed_Id] = InnerF.[Feed_Id] 
								WHERE InnerF.[FeedType_Name] = 'Docker' AND InnerF.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)') = 'True'),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [DockerRepositories] DR
							    WITH (READUNCOMMITTED)
									JOIN [Feeds] InnerF WITH (READUNCOMMITTED)
										ON DR.[Feed_Id] = InnerF.[Feed_Id] 
								WHERE InnerF.[FeedType_Name] = 'Docker' AND InnerF.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)') = 'True'),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [DockerImages] DI WITH (READUNCOMMITTED)
								JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
								  ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
									JOIN [Feeds] InnerF WITH (READUNCOMMITTED)
										ON DR.[Feed_Id] = InnerF.[Feed_Id] 
								WHERE InnerF.[FeedType_Name] = 'Docker' AND InnerF.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)') = 'True'),
		   [Feed_Size] = COALESCE((SELECT SUM(DB.[Blob_Size])
							FROM (SELECT DB.[DockerBlob_Id], DB.[Blob_Size]
								FROM [DockerBlobs] DB WITH (READUNCOMMITTED)
									 JOIN [DockerImageLayers] DIL WITH (READUNCOMMITTED)
									   ON DB.[DockerBlob_Id] = DIL.[DockerBlob_Id]
									 JOIN [DockerImages] DI WITH (READUNCOMMITTED)
									   ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
									 JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
									   ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
									JOIN [Feeds] InnerF WITH (READUNCOMMITTED)
										ON DR.[Feed_Id] = InnerF.[Feed_Id] 
								WHERE InnerF.[FeedType_Name] = 'Docker' AND InnerF.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)') = 'True'
							   GROUP BY DB.[DockerBlob_Id], DB.[Blob_Size]) DB

						   ), 0),
						   
		   [Cache_Size] = COALESCE((SELECT SUM(DB.[Blob_Size])
							FROM (SELECT DB.[DockerBlob_Id], DB.[Blob_Size]
								FROM [DockerBlobs] DB WITH (READUNCOMMITTED)
									 JOIN [DockerImageLayers] DIL WITH (READUNCOMMITTED)
									   ON DB.[DockerBlob_Id] = DIL.[DockerBlob_Id]
									 JOIN [DockerImages] DI WITH (READUNCOMMITTED)
									   ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
									  AND DI.[Cached_Indicator] = 'Y'
									 JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
									   ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
									JOIN [Feeds] InnerF WITH (READUNCOMMITTED)
										ON DR.[Feed_Id] = InnerF.[Feed_Id] 
								WHERE InnerF.[FeedType_Name] = 'Docker' AND InnerF.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)') = 'True'
							   GROUP BY DB.[DockerBlob_Id], DB.[Blob_Size]) DB
						   ), 0),
           [Active_Indicator] = 'Y',
		   [FeedConfiguration_Xml] = '<Inedo.ProGet.Feeds.Docker.DockerFeedConfig Assembly="ProGetCoreEx"><Properties UseCommonBlobStorage="True" /></Inedo.ProGet.Feeds.Docker.DockerFeedConfig>'
	 FROM [Feeds] F
	WHERE F.[FeedType_Name] = 'Docker' AND F.[FeedConfiguration_XML].value('(/Inedo.ProGet.Feeds.Docker.DockerFeedConfig/Properties/@UseCommonBlobStorage)[1]', 'nvarchar(6)') = 'True'
	GROUP BY F.[FeedType_Name]

END
GO

GRANT EXECUTE ON [DashboardFeeds_GetWithCombinedBlobStorage] TO [ProGetUser_Role]