EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ProGetPackages_IncrementDownloadCount',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Increments the download count for a ProGet package.'
GO

IF OBJECT_ID('[ProGetPackages_IncrementDownloadCount]') IS NOT NULL DROP PROCEDURE [ProGetPackages_IncrementDownloadCount]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ProGetPackages_IncrementDownloadCount]
(
	@Feed_Id INT,
	@Group_Name NVARCHAR(200),
	@Package_Name NVARCHAR(100),
	@Version_Text VARCHAR(255)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

	-- find and lock package row
	DECLARE @ProGetPackage_Id INT
	SET @ProGetPackage_Id = (SELECT [ProGetPackage_Id] 
	                           FROM [ProGetPackages] WITH (ROWLOCK) 
							  WHERE [Feed_Id] = @Feed_Id 
							    AND [Group_Name] = @Group_Name 
								AND [Package_Name] = @Package_Name)
	IF @ProGetPackage_Id IS NULL RETURN -1

	-- find total count and lock package versions table
	DECLARE @Total_Download_Count INT
	SET @Total_Download_Count = (SELECT SUM([Download_Count])
		                                FROM [ProGetPackageVersions] (TABLOCKX)
									    WHERE [ProGetPackage_Id] = @ProGetPackage_Id)

	-- update versions row (whole table already locked)
	UPDATE [ProGetPackageVersions]
	   SET [Download_Count] = [Download_Count] + 1
	 WHERE [ProGetPackage_Id] = @ProGetPackage_Id
	   AND [Version_Text] = @Version_Text

	-- update package row
	UPDATE [ProGetPackages]
	   SET [Download_Count] = COALESCE(@Total_Download_Count, 0) + 1
	 WHERE [ProGetPackage_Id] = @ProGetPackage_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ProGetPackages_IncrementDownloadCount] TO [ProGetUser_Role]
GO